@@ -17,12 +17,18 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# 操作未授权。
+AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
+
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
 # 请检查是否有权限。
 FAILEDOPERATION_AUTHERROR = 'FailedOperation.AuthError'
 
+# CAM鉴权出现错误。
+FAILEDOPERATION_CAMAUTHORIZEDFAIL = 'FailedOperation.CAMAuthorizedFail'
+
 # 取消订单失败。
 FAILEDOPERATION_CANCELORDERFAILED = 'FailedOperation.CancelOrderFailed'
 
@@ -38,6 +44,12 @@ FAILEDOPERATION_CANNOTGETORDER = 'FailedOperation.CannotGetOrder'
 # 证书已存在。
 FAILEDOPERATION_CERTIFICATEEXISTS = 'FailedOperation.CertificateExists'
 
+# 已替换证书，无法进行托管。
+FAILEDOPERATION_CERTIFICATEHASRENEWED = 'FailedOperation.CertificateHasRenewed'
+
+# 证书资源托管数量超过限制。
+FAILEDOPERATION_CERTIFICATEHOSTINGTYPENUMBERLIMIT = 'FailedOperation.CertificateHostingTypeNumberLimit'
+
 # 证书不符合标准。
 FAILEDOPERATION_CERTIFICATEINVALID = 'FailedOperation.CertificateInvalid'
 
@@ -65,6 +77,9 @@ FAILEDOPERATION_FILETOOLARGE = 'FailedOperation.FileTooLarge'
 # 文件尺寸太小，请上传清晰图片。
 FAILEDOPERATION_FILETOOSMALL = 'FailedOperation.FileTooSmall'
 
+# 公司管理人状态错误。
+FAILEDOPERATION_ILLEGALMANAGERSTATUS = 'FailedOperation.IllegalManagerStatus'
+
 # 证书来源错误。
 FAILEDOPERATION_INVALIDCERTIFICATESOURCE = 'FailedOperation.InvalidCertificateSource'
 
@@ -119,6 +134,12 @@ FAILEDOPERATION_ROLENOTFOUNDAUTHORIZATION = 'FailedOperation.RoleNotFoundAuthori
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
+# 后端服务响应为空。
+INTERNALERROR_BACKENDRESPONSEEMPTY = 'InternalError.BackendResponseEmpty'
+
+# 后端服务响应错误。
+INTERNALERROR_BACKENDRESPONSEERROR = 'InternalError.BackendResponseError'
+
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -131,6 +152,9 @@ INVALIDPARAMETER_CONTAINSINVALIDCERTIFICATEID = 'InvalidParameter.ContainsInvali
 # 权益点ID列表无效。
 INVALIDPARAMETER_PACKAGEIDSINVALID = 'InvalidParameter.PackageIdsInvalid'
 
+# 参数有误。
+INVALIDPARAMETER_WITHDETAILREASON = 'InvalidParameter.WithDetailReason'
+
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
